Please see [https://docs.mlcommons.org/cm4mlops/scripts/TinyML-automation/get-microtvm](https://docs.mlcommons.org/cm4mlops/scripts/TinyML-automation/get-microtvm) for the documentation of this CM script.
